@@ -1,3 +1,4 @@
+use std::collections::HashSet;
 use std::io::{self, Write};
 use std::sync::Arc;
 use std::time::Duration;
@@ -11,6 +12,7 @@ use tokio_stream::wrappers::ReceiverStream;
 use tokio_stream::StreamExt;
 
 use crate::formatters::response::ResponseFormatter;
+use crate::verbosity::{Verbosity, WarnLevel};
 use crate::{cache::Cache, stats::ResponseStats, ExitCode};
 use lychee_lib::{Client, Request, Response};
 
@@ -22,79 +24,50 @@ pub(crate) async fn check<S>(
 where
     S: futures::Stream<Item = Result<Request>>,
 {
+    // Setup
     let (send_req, recv_req) = mpsc::channel(params.cfg.max_concurrency);
-    let (send_resp, mut recv_resp) = mpsc::channel(params.cfg.max_concurrency);
+    let (send_resp, recv_resp) = mpsc::channel(params.cfg.max_concurrency);
     let max_concurrency = params.cfg.max_concurrency;
-    let mut stats = ResponseStats::new();
+    let stats = if params.cfg.verbose.is_verbose() {
+        ResponseStats::extended()
+    } else {
+        ResponseStats::default()
+    };
     let cache_ref = params.cache.clone();
 
     let client = params.client;
     let cache = params.cache;
-    // Start receiving requests
-    tokio::spawn(async move {
-        futures::StreamExt::for_each_concurrent(
-            ReceiverStream::new(recv_req),
-            max_concurrency,
-            |request: Result<Request>| async {
-                let request = request.expect("cannot read request");
-                let response = handle(&client, cache.clone(), request).await;
-
-                send_resp
-                    .send(response)
-                    .await
-                    .expect("cannot send response to queue");
-            },
-        )
-        .await;
-    });
+    let accept = params.cfg.accept;
 
     let pb = if params.cfg.no_progress {
         None
     } else {
-        let bar = ProgressBar::new_spinner().with_style(ProgressStyle::default_bar().template(
-            "{spinner:.red.bright} {pos}/{len:.dim} [{elapsed_precise}] {bar:25} {wide_msg}",
-        ).expect("Valid progress bar"));
-        bar.set_length(0);
-        bar.set_message("Extracting links");
-        // report status _at least_ every 500ms
-        bar.enable_steady_tick(Duration::from_millis(500));
-        Some(bar)
+        Some(init_progress_bar())
     };
 
-    let bar = pb.clone();
+    // Start receiving requests
+    tokio::spawn(request_channel_task(
+        recv_req,
+        send_resp,
+        max_concurrency,
+        client,
+        cache,
+        accept,
+    ));
 
-    let formatter = Arc::new(params.formatter);
+    let show_results_task = tokio::spawn(progress_bar_task(
+        recv_resp,
+        params.cfg.verbose,
+        pb.clone(),
+        Arc::new(params.formatter),
+        stats,
+    ));
 
-    let show_results_task = tokio::spawn({
-        let verbose = params.cfg.verbose;
-        async move {
-            while let Some(response) = recv_resp.recv().await {
-                show_progress(&mut io::stdout(), &pb, &response, &formatter, verbose)?;
-                stats.add(response);
-            }
-            Ok((pb, stats))
-        }
-    });
+    // Wait until all messages are sent
+    send_inputs_loop(params.requests, send_req, pb).await?;
 
-    let requests = params.requests;
-    tokio::pin!(requests);
-
-    while let Some(request) = requests.next().await {
-        let request = request?;
-        if let Some(pb) = &bar {
-            pb.inc_length(1);
-            pb.set_message(request.to_string());
-        };
-        send_req
-            .send(Ok(request))
-            .await
-            .expect("Cannot send request");
-    }
-    // required for the receiver task to end, which closes send_resp, which allows
-    // the show_results_task to finish
-    drop(send_req);
-
-    let result: Result<(_, _)> = show_results_task.await?;
+    // Wait until all responses are received
+    let result = show_results_task.await?;
     let (pb, stats) = result?;
 
     // Note that print statements may interfere with the progress bar, so this
@@ -111,8 +84,92 @@ where
     Ok((stats, cache_ref, code))
 }
 
+// drops the `send_req` channel on exit
+// required for the receiver task to end, which closes send_resp, which allows
+// the show_results_task to finish
+async fn send_inputs_loop<S>(
+    requests: S,
+    send_req: mpsc::Sender<Result<Request>>,
+    bar: Option<ProgressBar>,
+) -> Result<()>
+where
+    S: futures::Stream<Item = Result<Request>>,
+{
+    tokio::pin!(requests);
+    while let Some(request) = requests.next().await {
+        let request = request?;
+        if let Some(pb) = &bar {
+            pb.inc_length(1);
+            pb.set_message(request.to_string());
+        };
+        send_req
+            .send(Ok(request))
+            .await
+            .expect("Cannot send request");
+    }
+    Ok(())
+}
+
+/// Reads from the request channel and updates the progress bar status
+async fn progress_bar_task(
+    mut recv_resp: mpsc::Receiver<Response>,
+    verbose: Verbosity<WarnLevel>,
+    pb: Option<ProgressBar>,
+    formatter: Arc<Box<dyn ResponseFormatter>>,
+    mut stats: ResponseStats,
+) -> Result<(Option<ProgressBar>, ResponseStats)> {
+    while let Some(response) = recv_resp.recv().await {
+        show_progress(&mut io::stdout(), &pb, &response, &formatter, &verbose)?;
+        stats.add(response);
+    }
+    Ok((pb, stats))
+}
+
+fn init_progress_bar() -> ProgressBar {
+    let bar = ProgressBar::new_spinner().with_style(
+        ProgressStyle::with_template(
+            "{spinner:.197.bright} {pos}/{len:.dim} ETA {eta} {bar:.dim} {wide_msg}",
+        )
+        .expect("Valid progress bar"),
+    );
+    bar.set_length(0);
+    bar.set_message("Extracting links");
+    // report status _at least_ every 500ms
+    bar.enable_steady_tick(Duration::from_millis(500));
+    bar
+}
+
+async fn request_channel_task(
+    recv_req: mpsc::Receiver<Result<Request>>,
+    send_resp: mpsc::Sender<Response>,
+    max_concurrency: usize,
+    client: Client,
+    cache: Arc<Cache>,
+    accept: Option<HashSet<u16>>,
+) {
+    futures::StreamExt::for_each_concurrent(
+        ReceiverStream::new(recv_req),
+        max_concurrency,
+        |request: Result<Request>| async {
+            let request = request.expect("cannot read request");
+            let response = handle(&client, cache.clone(), request, accept.clone()).await;
+
+            send_resp
+                .send(response)
+                .await
+                .expect("cannot send response to queue");
+        },
+    )
+    .await;
+}
+
 /// Handle a single request
-async fn handle(client: &Client, cache: Arc<Cache>, request: Request) -> Response {
+async fn handle(
+    client: &Client,
+    cache: Arc<Cache>,
+    request: Request,
+    accept: Option<HashSet<u16>>,
+) -> Response {
     let uri = request.uri.clone();
     if let Some(v) = cache.get(&uri) {
         // Found a cached request
@@ -121,7 +178,11 @@ async fn handle(client: &Client, cache: Arc<Cache>, request: Request) -> Respons
         let status = if client.is_excluded(&uri) {
             Status::Excluded
         } else {
-            Status::from(v.value().status)
+            // Can't impl `Status::from(v.value().status)` here because the
+            // `accepted` status codes might have changed from the previous run
+            // and they may have an impact on the interpretation of the status
+            // code.
+            Status::from_cache_status(v.value().status, accept)
         };
         return Response::new(uri.clone(), status, request.source);
     }
@@ -151,23 +212,26 @@ fn show_progress(
     progress_bar: &Option<ProgressBar>,
     response: &Response,
     formatter: &Arc<Box<dyn ResponseFormatter>>,
-    verbose: bool,
+    verbose: &Verbosity<WarnLevel>,
 ) -> Result<()> {
     let out = formatter.write_response(response)?;
     if let Some(pb) = progress_bar {
         pb.inc(1);
         pb.set_message(out.clone());
-        if verbose {
+        if verbose.is_verbose() {
             pb.println(out);
         }
-    } else if verbose || (!response.status().is_success() && !response.status().is_excluded()) {
-        writeln!(output, "{}", out)?;
+    } else if verbose.is_verbose()
+        || (!response.status().is_success() && !response.status().is_excluded())
+    {
+        writeln!(output, "{out}")?;
     }
     Ok(())
 }
 
 #[cfg(test)]
 mod tests {
+    use log::info;
     use lychee_lib::{CacheStatus, InputSource, ResponseBody, Uri};
 
     use crate::formatters;
@@ -186,9 +250,16 @@ mod tests {
         );
         let formatter: Arc<Box<dyn ResponseFormatter>> =
             Arc::new(Box::new(formatters::response::Raw::new()));
-        show_progress(&mut buf, &None, &response, &formatter, false).unwrap();
+        show_progress(
+            &mut buf,
+            &None,
+            &response,
+            &formatter,
+            &Verbosity::new(0, 0),
+        )
+        .unwrap();
 
-        println!("{:?}", String::from_utf8_lossy(&buf));
+        info!("{:?}", String::from_utf8_lossy(&buf));
         assert!(buf.is_empty());
     }
 }
