@@ -19,6 +19,7 @@ mod cli {
     // constant.
     const LYCHEE_CACHE_FILE: &str = ".lycheecache";
 
+    /// Helper macro to create a mock server which returns a custom status code.
     macro_rules! mock_server {
         ($status:expr $(, $func:tt ($($arg:expr),*))*) => {{
             let mock_server = wiremock::MockServer::start().await;
@@ -29,11 +30,25 @@ mod cli {
         }};
     }
 
+    /// Helper macro to create a mock server which returns a 200 OK and a custom response body.
+    macro_rules! mock_response {
+        ($body:expr) => {{
+            let mock_server = wiremock::MockServer::start().await;
+            let template = wiremock::ResponseTemplate::new(200).set_body_string($body);
+            wiremock::Mock::given(wiremock::matchers::method("GET"))
+                .respond_with(template)
+                .mount(&mock_server)
+                .await;
+            mock_server
+        }};
+    }
+
+    /// Gets the "main" binary name (e.g. `lychee`)
     fn main_command() -> Command {
-        // this gets the "main" binary name (e.g. `lychee`)
         Command::cargo_bin(env!("CARGO_PKG_NAME")).expect("Couldn't get cargo package name")
     }
 
+    /// Helper function to get the path to the fixtures directory.
     fn fixtures_path() -> PathBuf {
         Path::new(env!("CARGO_MANIFEST_DIR"))
             .parent()
@@ -82,6 +97,7 @@ mod cli {
         }
     }
 
+    /// Helper macro to test the output of the JSON format.
     macro_rules! test_json_output {
         ($test_file:expr, $expected:expr $(, $arg:expr)*) => {{
             let mut cmd = main_command();
@@ -771,6 +787,95 @@ mod cli {
         Ok(())
     }
 
+    #[tokio::test]
+    async fn test_lycheecache_accept_custom_status_codes() -> Result<()> {
+        let base_path = fixtures_path().join("cache");
+        let cache_file = base_path.join(LYCHEE_CACHE_FILE);
+
+        // Unconditionally remove cache file if it exists
+        let _ = fs::remove_file(&cache_file);
+
+        let mock_server_ok = mock_server!(StatusCode::OK);
+        let mock_server_teapot = mock_server!(StatusCode::IM_A_TEAPOT);
+        let mock_server_server_error = mock_server!(StatusCode::INTERNAL_SERVER_ERROR);
+
+        let dir = tempfile::tempdir()?;
+        let mut file = File::create(dir.path().join("c.md"))?;
+
+        writeln!(file, "{}", mock_server_ok.uri().as_str())?;
+        writeln!(file, "{}", mock_server_teapot.uri().as_str())?;
+        writeln!(file, "{}", mock_server_server_error.uri().as_str())?;
+
+        let mut cmd = main_command();
+        let test_cmd = cmd
+            .current_dir(&base_path)
+            .arg(dir.path().join("c.md"))
+            .arg("--verbose")
+            .arg("--cache");
+
+        assert!(
+            !cache_file.exists(),
+            "cache file should not exist before this test"
+        );
+
+        // run first without cache to generate the cache file
+        // ignore exit code
+        test_cmd
+            .assert()
+            .failure()
+            .code(2)
+            .stdout(contains(format!(
+                "[418] {}/ | Failed: Network error: I'm a teapot\n",
+                mock_server_teapot.uri()
+            )))
+            .stdout(contains(format!(
+                "[500] {}/ | Failed: Network error: Internal Server Error\n",
+                mock_server_server_error.uri()
+            )));
+
+        // check content of cache file
+        let data = fs::read_to_string(&cache_file)?;
+        assert!(data.contains(&format!("{}/,200", mock_server_ok.uri())));
+        assert!(data.contains(&format!("{}/,418", mock_server_teapot.uri())));
+        assert!(data.contains(&format!("{}/,500", mock_server_server_error.uri())));
+
+        // run again to verify cache behavior
+        // this time accept 418 and 500 as valid status codes
+        test_cmd
+            .arg("--no-progress")
+            .arg("--accept")
+            .arg("418,500")
+            .assert()
+            .success()
+            .stdout(contains(format!(
+                "[418] {}/ | Cached: OK (cached)\n",
+                mock_server_teapot.uri()
+            )))
+            .stdout(contains(format!(
+                "[500] {}/ | Cached: OK (cached)\n",
+                mock_server_server_error.uri()
+            )));
+
+        // clear the cache file
+        fs::remove_file(&cache_file)?;
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_verbatim_skipped_by_default() -> Result<()> {
+        let mut cmd = main_command();
+        let input = fixtures_path().join("TEST_CODE_BLOCKS.md");
+
+        cmd.arg(input)
+            .arg("--dump")
+            .assert()
+            .success()
+            .stdout(is_empty());
+
+        Ok(())
+    }
+
     #[test]
     fn test_include_verbatim() -> Result<()> {
         let mut cmd = main_command();
@@ -788,13 +893,15 @@ mod cli {
         Ok(())
     }
 
-    #[test]
-    fn test_exclude_verbatim() -> Result<()> {
+    #[tokio::test]
+    async fn test_verbatim_skipped_by_default_via_remote_url() -> Result<()> {
         let mut cmd = main_command();
-        let input = fixtures_path().join("TEST_CODE_BLOCKS.md");
+        let file = fixtures_path().join("TEST_VERBATIM.html");
+        let body = fs::read_to_string(file)?;
+        let mock_server = mock_response!(body);
 
-        cmd.arg(input)
-            .arg("--dump")
+        cmd.arg("--dump")
+            .arg(mock_server.uri())
             .assert()
             .success()
             .stdout(is_empty());
@@ -802,6 +909,28 @@ mod cli {
         Ok(())
     }
 
+    #[tokio::test]
+    async fn test_include_verbatim_via_remote_url() -> Result<()> {
+        let mut cmd = main_command();
+        let file = fixtures_path().join("TEST_VERBATIM.html");
+        let body = fs::read_to_string(file)?;
+        let mock_server = mock_response!(body);
+
+        cmd.arg("--include-verbatim")
+            .arg("--dump")
+            .arg(mock_server.uri())
+            .assert()
+            .success()
+            .stdout(contains("http://www.example.com/pre"))
+            .stdout(contains("http://www.example.com/code"))
+            .stdout(contains("http://www.example.com/samp"))
+            .stdout(contains("http://www.example.com/kbd"))
+            .stdout(contains("http://www.example.com/var"))
+            .stdout(contains("http://www.example.com/address"))
+            .stdout(contains("http://www.example.com/script"));
+        Ok(())
+    }
+
     #[test]
     fn test_require_https() -> Result<()> {
         let mut cmd = main_command();
