@@ -67,8 +67,8 @@ pub enum ErrorKind {
     #[error("Error with base dir `{0}` : {1}")]
     InvalidBase(String, String),
     /// The given input can not be parsed into a valid URI remapping
-    #[error("Error handling URI remap expression. Cannot parse into URI remapping: `{0}`")]
-    InvalidUriRemap(String),
+    #[error("Cannot parse into URI remapping, must be a Regex pattern and a URL separated by whitespaces: `{0}`")]
+    InvalidUrlRemap(String),
     /// The given path does not resolve to a valid file
     #[error("Cannot find local file {0}")]
     FileNotFound(PathBuf),
@@ -93,6 +93,9 @@ pub enum ErrorKind {
     /// Cannot parse the given URI
     #[error("The given URI is invalid: {0}")]
     InvalidURI(Uri),
+    /// The given status code is invalid (not in the range 100-1000)
+    #[error("Invalid status code: {0}")]
+    InvalidStatusCode(u16),
     /// Regex error
     #[error("Error when using regex engine: {0}")]
     Regex(#[from] regex::Error),
@@ -158,6 +161,12 @@ impl PartialEq for ErrorKind {
             }
             (Self::InvalidHeader(_), Self::InvalidHeader(_))
             | (Self::MissingGitHubToken, Self::MissingGitHubToken) => true,
+            (Self::InvalidStatusCode(c1), Self::InvalidStatusCode(c2)) => c1 == c2,
+            (Self::InvalidUrlHost, Self::InvalidUrlHost) => true,
+            (Self::InvalidURI(u1), Self::InvalidURI(u2)) => u1 == u2,
+            (Self::Regex(e1), Self::Regex(e2)) => e1.to_string() == e2.to_string(),
+            (Self::DirTraversal(e1), Self::DirTraversal(e2)) => e1.to_string() == e2.to_string(),
+            (Self::Channel(_), Self::Channel(_)) => true,
             _ => false,
         }
     }
@@ -192,9 +201,10 @@ impl Hash for ErrorKind {
             Self::UnreachableEmailAddress(u, ..) => u.hash(state),
             Self::InsecureURL(u, ..) => u.hash(state),
             Self::InvalidBase(base, e) => (base, e).hash(state),
-            Self::InvalidUriRemap(remap) => (remap).hash(state),
+            Self::InvalidUrlRemap(remap) => (remap).hash(state),
             Self::InvalidHeader(e) => e.to_string().hash(state),
             Self::InvalidGlobPattern(e) => e.to_string().hash(state),
+            Self::InvalidStatusCode(c) => c.hash(state),
             Self::Channel(e) => e.to_string().hash(state),
             Self::MissingGitHubToken | Self::InvalidUrlHost => {
                 std::mem::discriminant(self).hash(state);
