@@ -94,6 +94,13 @@ impl Uri {
         self.scheme() == "file"
     }
 
+    #[inline]
+    #[must_use]
+    /// Check if the URI is a `data` URI
+    pub fn is_data(&self) -> bool {
+        self.scheme() == "data"
+    }
+
     #[inline]
     #[must_use]
     /// Returns `true` if this is a loopback address.
